# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from mozart_api.api_client import ApiClient
from mozart_api.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class BeolinkApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_beolink_available_listeners(self, **kwargs):  # noqa: E501
        """Get available listeners  # noqa: E501

        Get a list of devices that can be listening to this device active experience.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_beolink_available_listeners(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[BeolinkAvailableListener]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_beolink_available_listeners_with_http_info(
            **kwargs
        )  # noqa: E501

    def get_beolink_available_listeners_with_http_info(self, **kwargs):  # noqa: E501
        """Get available listeners  # noqa: E501

        Get a list of devices that can be listening to this device active experience.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_beolink_available_listeners_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[BeolinkAvailableListener], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_beolink_available_listeners" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/beolink/available-listeners",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[BeolinkAvailableListener]",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_beolink_join_result(self, id, **kwargs):  # noqa: E501
        """Get Beolink join result, test-endpoint  # noqa: E501

        Returns the result of a join request.  **WARNING:** This end-point is only for testing purposes. Only a limited number of results are kept, so if there are multiple API clients using the device at the same time, and you are polling this end-point, you may miss the result of your join request.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_beolink_join_result(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: Join request ID (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: BeolinkJoinResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_beolink_join_result_with_http_info(id, **kwargs)  # noqa: E501

    def get_beolink_join_result_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get Beolink join result, test-endpoint  # noqa: E501

        Returns the result of a join request.  **WARNING:** This end-point is only for testing purposes. Only a limited number of results are kept, so if there are multiple API clients using the device at the same time, and you are polling this end-point, you may miss the result of your join request.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_beolink_join_result_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: Join request ID (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(BeolinkJoinResult, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["id"]
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_beolink_join_result" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and (
            "id" not in local_var_params or local_var_params["id"] is None  # noqa: E501
        ):  # noqa: E501
            raise ApiValueError(
                "Missing the required parameter `id` when calling `get_beolink_join_result`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "id" in local_var_params:
            path_params["id"] = local_var_params["id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/beolink/join-result/{id}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="BeolinkJoinResult",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_beolink_listeners(self, **kwargs):  # noqa: E501
        """Get joined peers  # noqa: E501

        Get a list of devices that are listening to this device active experience (that have joined).   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_beolink_listeners(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[BeolinkListener]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_beolink_listeners_with_http_info(**kwargs)  # noqa: E501

    def get_beolink_listeners_with_http_info(self, **kwargs):  # noqa: E501
        """Get joined peers  # noqa: E501

        Get a list of devices that are listening to this device active experience (that have joined).   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_beolink_listeners_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[BeolinkListener], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_beolink_listeners" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/beolink/listeners",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[BeolinkListener]",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_beolink_peers(self, **kwargs):  # noqa: E501
        """Get discovered peers  # noqa: E501

        Get information about the Beolink peers discovered by this device.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_beolink_peers(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[BeolinkPeer]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_beolink_peers_with_http_info(**kwargs)  # noqa: E501

    def get_beolink_peers_with_http_info(self, **kwargs):  # noqa: E501
        """Get discovered peers  # noqa: E501

        Get information about the Beolink peers discovered by this device.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_beolink_peers_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[BeolinkPeer], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_beolink_peers" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/beolink/peers",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[BeolinkPeer]",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_beolink_self(self, **kwargs):  # noqa: E501
        """Get information about this device  # noqa: E501

        Returns Beolink information like about this device. This can be useful if you want to expand _to_ this device.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_beolink_self(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: BeolinkPeer
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_beolink_self_with_http_info(**kwargs)  # noqa: E501

    def get_beolink_self_with_http_info(self, **kwargs):  # noqa: E501
        """Get information about this device  # noqa: E501

        Returns Beolink information like about this device. This can be useful if you want to expand _to_ this device.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_beolink_self_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(BeolinkPeer, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_beolink_self" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/beolink/self",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="BeolinkPeer",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def join_beolink_peer(self, jid, **kwargs):  # noqa: E501
        """Join multi-room experience  # noqa: E501

        Join the experience currently active on peer with Jabber ID `{jid}`.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.join_beolink_peer(jid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str jid: Jabber ID of peer to join (required)
        :param str source: Ask to join a specific source on peer
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: BeolinkJoinRequest
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.join_beolink_peer_with_http_info(jid, **kwargs)  # noqa: E501

    def join_beolink_peer_with_http_info(self, jid, **kwargs):  # noqa: E501
        """Join multi-room experience  # noqa: E501

        Join the experience currently active on peer with Jabber ID `{jid}`.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.join_beolink_peer_with_http_info(jid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str jid: Jabber ID of peer to join (required)
        :param str source: Ask to join a specific source on peer
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(BeolinkJoinRequest, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["jid", "source"]
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method join_beolink_peer" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'jid' is set
        if self.api_client.client_side_validation and (
            "jid" not in local_var_params
            or local_var_params["jid"] is None  # noqa: E501
        ):  # noqa: E501
            raise ApiValueError(
                "Missing the required parameter `jid` when calling `join_beolink_peer`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "jid" in local_var_params:
            path_params["jid"] = local_var_params["jid"]  # noqa: E501

        query_params = []
        if (
            "source" in local_var_params and local_var_params["source"] is not None
        ):  # noqa: E501
            query_params.append(("source", local_var_params["source"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/beolink/join/{jid}",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="BeolinkJoinRequest",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def join_latest_beolink_experience(self, **kwargs):  # noqa: E501
        """Trigger touch to join  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.join_latest_beolink_experience(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: BeolinkJoinRequest
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.join_latest_beolink_experience_with_http_info(
            **kwargs
        )  # noqa: E501

    def join_latest_beolink_experience_with_http_info(self, **kwargs):  # noqa: E501
        """Trigger touch to join  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.join_latest_beolink_experience_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(BeolinkJoinRequest, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method join_latest_beolink_experience" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/beolink/join",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="BeolinkJoinRequest",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def post_beolink_allstandby(self, **kwargs):  # noqa: E501
        """Broadcast an all standby event to turn all Beolink devices off  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_beolink_allstandby(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.post_beolink_allstandby_with_http_info(**kwargs)  # noqa: E501

    def post_beolink_allstandby_with_http_info(self, **kwargs):  # noqa: E501
        """Broadcast an all standby event to turn all Beolink devices off  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_beolink_allstandby_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_beolink_allstandby" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/beolink/allstandby",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def post_beolink_expand(self, jid, **kwargs):  # noqa: E501
        """Expand the current active experience  # noqa: E501

        Expand the current active experience to another device with jabber id `{jid}`.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_beolink_expand(jid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str jid: Jabber id of peer to expand the active experience to (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.post_beolink_expand_with_http_info(jid, **kwargs)  # noqa: E501

    def post_beolink_expand_with_http_info(self, jid, **kwargs):  # noqa: E501
        """Expand the current active experience  # noqa: E501

        Expand the current active experience to another device with jabber id `{jid}`.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_beolink_expand_with_http_info(jid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str jid: Jabber id of peer to expand the active experience to (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["jid"]
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_beolink_expand" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'jid' is set
        if self.api_client.client_side_validation and (
            "jid" not in local_var_params
            or local_var_params["jid"] is None  # noqa: E501
        ):  # noqa: E501
            raise ApiValueError(
                "Missing the required parameter `jid` when calling `post_beolink_expand`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "jid" in local_var_params:
            path_params["jid"] = local_var_params["jid"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/beolink/expand/{jid}",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def post_beolink_leave(self, **kwargs):  # noqa: E501
        """Leave the ongoing experience (disconnect this device from remote)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_beolink_leave(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.post_beolink_leave_with_http_info(**kwargs)  # noqa: E501

    def post_beolink_leave_with_http_info(self, **kwargs):  # noqa: E501
        """Leave the ongoing experience (disconnect this device from remote)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_beolink_leave_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_beolink_leave" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/beolink/leave",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def post_beolink_unexpand(self, jid, **kwargs):  # noqa: E501
        """Unexpand (disconnect) a device from the multiroom session  # noqa: E501

        Disconnect the device with jabber id `{jid}` from the current active experience.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_beolink_unexpand(jid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str jid: Jabber id of peer to unexpand (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.post_beolink_unexpand_with_http_info(jid, **kwargs)  # noqa: E501

    def post_beolink_unexpand_with_http_info(self, jid, **kwargs):  # noqa: E501
        """Unexpand (disconnect) a device from the multiroom session  # noqa: E501

        Disconnect the device with jabber id `{jid}` from the current active experience.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_beolink_unexpand_with_http_info(jid, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str jid: Jabber id of peer to unexpand (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["jid"]
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_beolink_unexpand" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'jid' is set
        if self.api_client.client_side_validation and (
            "jid" not in local_var_params
            or local_var_params["jid"] is None  # noqa: E501
        ):  # noqa: E501
            raise ApiValueError(
                "Missing the required parameter `jid` when calling `post_beolink_unexpand`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "jid" in local_var_params:
            path_params["jid"] = local_var_params["jid"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/beolink/unexpand/{jid}",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional

from mozart_api.models.microphones_state import MicrophonesState
from mozart_api.models.power_state_enum import PowerStateEnum
from mozart_api.models.tv_state import TvState
from mozart_api.models.playback_state import PlaybackState
from mozart_api.models.source import Source
from mozart_api.models.software_update_state import SoftwareUpdateState
from mozart_api.models.volume_state import VolumeState
from mozart_api.models.sound_settings import SoundSettings

from mozart_api.configuration import Configuration


class ProductState(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "microphones": "MicrophonesState",
        "playback": "PlaybackState",
        "power_state": "PowerStateEnum",
        "software_update_state": "SoftwareUpdateState",
        "sound_settings": "SoundSettings",
        "source": "Source",
        "tv": "TvState",
        "volume": "VolumeState",
    }

    attribute_map = {
        "microphones": "microphones",
        "playback": "playback",
        "power_state": "powerState",
        "software_update_state": "softwareUpdateState",
        "sound_settings": "soundSettings",
        "source": "source",
        "tv": "tv",
        "volume": "volume",
    }

    def __init__(
        self,
        microphones: Optional[MicrophonesState] = None,
        playback: Optional[PlaybackState] = None,
        power_state: Optional[PowerStateEnum] = None,
        software_update_state: Optional[SoftwareUpdateState] = None,
        sound_settings: Optional[SoundSettings] = None,
        source: Optional[Source] = None,
        tv: Optional[TvState] = None,
        volume: Optional[VolumeState] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """ProductState - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._microphones = None
        self._playback = None
        self._power_state = None
        self._software_update_state = None
        self._sound_settings = None
        self._source = None
        self._tv = None
        self._volume = None
        self.discriminator = None

        if microphones is not None:
            self.microphones = microphones
        if playback is not None:
            self.playback = playback
        if power_state is not None:
            self.power_state = power_state
        if software_update_state is not None:
            self.software_update_state = software_update_state
        if sound_settings is not None:
            self.sound_settings = sound_settings
        if source is not None:
            self.source = source
        if tv is not None:
            self.tv = tv
        if volume is not None:
            self.volume = volume

    @property
    def microphones(self):
        # type: () -> MicrophonesState
        """Gets the microphones of this ProductState.  # noqa: E501


        :return: The microphones of this ProductState.  # noqa: E501
        :rtype: MicrophonesState
        """
        return self._microphones

    @microphones.setter
    def microphones(self, microphones):
        # type: (MicrophonesState) -> None
        """Sets the microphones of this ProductState.


        :param microphones: The microphones of this ProductState.  # noqa: E501
        :type microphones: MicrophonesState
        :rtype: None
        """

        self._microphones = microphones

    @property
    def playback(self):
        # type: () -> PlaybackState
        """Gets the playback of this ProductState.  # noqa: E501


        :return: The playback of this ProductState.  # noqa: E501
        :rtype: PlaybackState
        """
        return self._playback

    @playback.setter
    def playback(self, playback):
        # type: (PlaybackState) -> None
        """Sets the playback of this ProductState.


        :param playback: The playback of this ProductState.  # noqa: E501
        :type playback: PlaybackState
        :rtype: None
        """

        self._playback = playback

    @property
    def power_state(self):
        # type: () -> PowerStateEnum
        """Gets the power_state of this ProductState.  # noqa: E501


        :return: The power_state of this ProductState.  # noqa: E501
        :rtype: PowerStateEnum
        """
        return self._power_state

    @power_state.setter
    def power_state(self, power_state):
        # type: (PowerStateEnum) -> None
        """Sets the power_state of this ProductState.


        :param power_state: The power_state of this ProductState.  # noqa: E501
        :type power_state: PowerStateEnum
        :rtype: None
        """

        self._power_state = power_state

    @property
    def software_update_state(self):
        # type: () -> SoftwareUpdateState
        """Gets the software_update_state of this ProductState.  # noqa: E501


        :return: The software_update_state of this ProductState.  # noqa: E501
        :rtype: SoftwareUpdateState
        """
        return self._software_update_state

    @software_update_state.setter
    def software_update_state(self, software_update_state):
        # type: (SoftwareUpdateState) -> None
        """Sets the software_update_state of this ProductState.


        :param software_update_state: The software_update_state of this ProductState.  # noqa: E501
        :type software_update_state: SoftwareUpdateState
        :rtype: None
        """

        self._software_update_state = software_update_state

    @property
    def sound_settings(self):
        # type: () -> SoundSettings
        """Gets the sound_settings of this ProductState.  # noqa: E501


        :return: The sound_settings of this ProductState.  # noqa: E501
        :rtype: SoundSettings
        """
        return self._sound_settings

    @sound_settings.setter
    def sound_settings(self, sound_settings):
        # type: (SoundSettings) -> None
        """Sets the sound_settings of this ProductState.


        :param sound_settings: The sound_settings of this ProductState.  # noqa: E501
        :type sound_settings: SoundSettings
        :rtype: None
        """

        self._sound_settings = sound_settings

    @property
    def source(self):
        # type: () -> Source
        """Gets the source of this ProductState.  # noqa: E501


        :return: The source of this ProductState.  # noqa: E501
        :rtype: Source
        """
        return self._source

    @source.setter
    def source(self, source):
        # type: (Source) -> None
        """Sets the source of this ProductState.


        :param source: The source of this ProductState.  # noqa: E501
        :type source: Source
        :rtype: None
        """

        self._source = source

    @property
    def tv(self):
        # type: () -> TvState
        """Gets the tv of this ProductState.  # noqa: E501


        :return: The tv of this ProductState.  # noqa: E501
        :rtype: TvState
        """
        return self._tv

    @tv.setter
    def tv(self, tv):
        # type: (TvState) -> None
        """Sets the tv of this ProductState.


        :param tv: The tv of this ProductState.  # noqa: E501
        :type tv: TvState
        :rtype: None
        """

        self._tv = tv

    @property
    def volume(self):
        # type: () -> VolumeState
        """Gets the volume of this ProductState.  # noqa: E501


        :return: The volume of this ProductState.  # noqa: E501
        :rtype: VolumeState
        """
        return self._volume

    @volume.setter
    def volume(self, volume):
        # type: (VolumeState) -> None
        """Sets the volume of this ProductState.


        :param volume: The volume of this ProductState.  # noqa: E501
        :type volume: VolumeState
        :rtype: None
        """

        self._volume = volume

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProductState):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProductState):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional

from mozart_api.models.video_pixel_format import VideoPixelFormat
from mozart_api.models.video_timings import VideoTimings

from mozart_api.configuration import Configuration


class HdmiVideoFormat(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "pixel_format": "VideoPixelFormat",
        "v_ic": "int",
        "video_timings": "VideoTimings",
    }

    attribute_map = {
        "pixel_format": "pixelFormat",
        "v_ic": "vIC",
        "video_timings": "videoTimings",
    }

    def __init__(
        self,
        pixel_format: Optional[VideoPixelFormat] = None,
        v_ic: Optional[int] = None,
        video_timings: Optional[VideoTimings] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """HdmiVideoFormat - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._pixel_format = None
        self._v_ic = None
        self._video_timings = None
        self.discriminator = None

        if pixel_format is not None:
            self.pixel_format = pixel_format
        if v_ic is not None:
            self.v_ic = v_ic
        if video_timings is not None:
            self.video_timings = video_timings

    @property
    def pixel_format(self):
        # type: () -> VideoPixelFormat
        """Gets the pixel_format of this HdmiVideoFormat.  # noqa: E501


        :return: The pixel_format of this HdmiVideoFormat.  # noqa: E501
        :rtype: VideoPixelFormat
        """
        return self._pixel_format

    @pixel_format.setter
    def pixel_format(self, pixel_format):
        # type: (VideoPixelFormat) -> None
        """Sets the pixel_format of this HdmiVideoFormat.


        :param pixel_format: The pixel_format of this HdmiVideoFormat.  # noqa: E501
        :type pixel_format: VideoPixelFormat
        :rtype: None
        """

        self._pixel_format = pixel_format

    @property
    def v_ic(self):
        # type: () -> int
        """Gets the v_ic of this HdmiVideoFormat.  # noqa: E501


        :return: The v_ic of this HdmiVideoFormat.  # noqa: E501
        :rtype: int
        """
        return self._v_ic

    @v_ic.setter
    def v_ic(self, v_ic):
        # type: (int) -> None
        """Sets the v_ic of this HdmiVideoFormat.


        :param v_ic: The v_ic of this HdmiVideoFormat.  # noqa: E501
        :type v_ic: int
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation
            and v_ic is not None
            and v_ic < 0
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `v_ic`, must be a value greater than or equal to `0`"
            )  # noqa: E501

        self._v_ic = v_ic

    @property
    def video_timings(self):
        # type: () -> VideoTimings
        """Gets the video_timings of this HdmiVideoFormat.  # noqa: E501


        :return: The video_timings of this HdmiVideoFormat.  # noqa: E501
        :rtype: VideoTimings
        """
        return self._video_timings

    @video_timings.setter
    def video_timings(self, video_timings):
        # type: (VideoTimings) -> None
        """Sets the video_timings of this HdmiVideoFormat.


        :param video_timings: The video_timings of this HdmiVideoFormat.  # noqa: E501
        :type video_timings: VideoTimings
        :rtype: None
        """

        self._video_timings = video_timings

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HdmiVideoFormat):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, HdmiVideoFormat):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mozart_api
from mozart_api.models.room_compensation_result import (
    RoomCompensationResult,
)  # noqa: E501
from mozart_api.rest import ApiException


class TestRoomCompensationResult(unittest.TestCase):
    """RoomCompensationResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test RoomCompensationResult
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # model = mozart_api.models.room_compensation_result.RoomCompensationResult()  # noqa: E501
        if include_optional:
            return RoomCompensationResult(
                compensation=[
                    mozart_api.models.room_compensation_response.RoomCompensationResponse(
                        frequency=56,
                        gain=1.337,
                    )
                ],
                measured_response=[
                    mozart_api.models.room_compensation_response.RoomCompensationResponse(
                        frequency=56,
                        gain=1.337,
                    )
                ],
                placement="free",
                reference_response=[
                    mozart_api.models.room_compensation_response.RoomCompensationResponse(
                        frequency=56,
                        gain=1.337,
                    )
                ],
                speaker_group_suggestion=mozart_api.models.speaker_group.SpeakerGroup(
                    crossover_frequency=20,
                    enable_phase_compensation=True,
                    friendly_name="0",
                    id="0",
                    is_deleteable=True,
                    items=[
                        mozart_api.models.speaker_group_member.SpeakerGroupMember(
                            distance=0,
                            friendly_name="0",
                            gain=-24,
                            id="0",
                            location=mozart_api.models.speaker_group_member_location.SpeakerGroupMember_location(
                                x=56,
                                y=56,
                                z=56,
                            ),
                            redirection_level=-100,
                            role="0",
                            type="0",
                        )
                    ],
                    room_compensation_id="0",
                    speaker_preset=0,
                ),
                time_stamp=datetime.datetime.strptime(
                    "2013-10-20 19:20:30.00", "%Y-%m-%d %H:%M:%S.%f"
                ),
            )
        else:
            return RoomCompensationResult()

    def testRoomCompensationResult(self):
        """Test RoomCompensationResult"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional


from mozart_api.configuration import Configuration


class BeolinkJoinResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "error": "str",
        "jid": "str",
        "request_id": "str",
        "status": "str",
        "type": "str",
    }

    attribute_map = {
        "error": "error",
        "jid": "jid",
        "request_id": "requestID",
        "status": "status",
        "type": "type",
    }

    def __init__(
        self,
        error: Optional["BeolinkJoinResult.LTypeError"] = None,
        jid: Optional[str] = None,
        request_id: Optional[str] = None,
        status: Optional["BeolinkJoinResult.LTypeStatus"] = None,
        type: Optional["BeolinkJoinResult.LTypeType"] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """BeolinkJoinResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._error = None
        self._jid = None
        self._request_id = None
        self._status = None
        self._type = None
        self.discriminator = None

        if error is not None:
            self.error = error
        self.jid = jid
        self.request_id = request_id
        self.status = status
        self.type = type

    LTypeError = Literal[
        "ok", "busy", "leaderless", "alone", "silent", "missing", "rejected", "timeout"
    ]

    @property
    def error(self):
        # type: () -> 'BeolinkJoinResult.LTypeError'
        """Gets the error of this BeolinkJoinResult.  # noqa: E501

        Join error  # noqa: E501

        :return: The error of this BeolinkJoinResult.  # noqa: E501
        :rtype: 'BeolinkJoinResult.LTypeError'
        """
        return self._error

    @error.setter
    def error(self, error):
        # type: ('BeolinkJoinResult.LTypeError') -> None
        """Sets the error of this BeolinkJoinResult.

        Join error  # noqa: E501

        :param error: The error of this BeolinkJoinResult.  # noqa: E501
        :type error: 'BeolinkJoinResult.LTypeError'
        :rtype: None
        """
        allowed_values = [
            "ok",
            "busy",
            "leaderless",
            "alone",
            "silent",
            "missing",
            "rejected",
            "timeout",
        ]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and error not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `error` ({0}), must be one of {1}".format(  # noqa: E501
                    error, allowed_values
                )
            )

        self._error = error

    @property
    def jid(self):
        # type: () -> str
        """Gets the jid of this BeolinkJoinResult.  # noqa: E501

        Beolink peer ID  # noqa: E501

        :return: The jid of this BeolinkJoinResult.  # noqa: E501
        :rtype: str
        """
        return self._jid

    @jid.setter
    def jid(self, jid):
        # type: (str) -> None
        """Sets the jid of this BeolinkJoinResult.

        Beolink peer ID  # noqa: E501

        :param jid: The jid of this BeolinkJoinResult.  # noqa: E501
        :type jid: str
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation and jid is None
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `jid`, must not be `None`"
            )  # noqa: E501

        self._jid = jid

    @property
    def request_id(self):
        # type: () -> str
        """Gets the request_id of this BeolinkJoinResult.  # noqa: E501

        Beolink request ID  # noqa: E501

        :return: The request_id of this BeolinkJoinResult.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        # type: (str) -> None
        """Sets the request_id of this BeolinkJoinResult.

        Beolink request ID  # noqa: E501

        :param request_id: The request_id of this BeolinkJoinResult.  # noqa: E501
        :type request_id: str
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation and request_id is None
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `request_id`, must not be `None`"
            )  # noqa: E501

        self._request_id = request_id

    LTypeStatus = Literal["idle", "joined", "failed"]

    @property
    def status(self):
        # type: () -> 'BeolinkJoinResult.LTypeStatus'
        """Gets the status of this BeolinkJoinResult.  # noqa: E501

        Overall join status  # noqa: E501

        :return: The status of this BeolinkJoinResult.  # noqa: E501
        :rtype: 'BeolinkJoinResult.LTypeStatus'
        """
        return self._status

    @status.setter
    def status(self, status):
        # type: ('BeolinkJoinResult.LTypeStatus') -> None
        """Sets the status of this BeolinkJoinResult.

        Overall join status  # noqa: E501

        :param status: The status of this BeolinkJoinResult.  # noqa: E501
        :type status: 'BeolinkJoinResult.LTypeStatus'
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation and status is None
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `status`, must not be `None`"
            )  # noqa: E501
        allowed_values = ["idle", "joined", "failed"]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and status not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}".format(  # noqa: E501
                    status, allowed_values
                )
            )

        self._status = status

    LTypeType = Literal["join", "joinRequested", "expand", "expandRequested"]

    @property
    def type(self):
        # type: () -> 'BeolinkJoinResult.LTypeType'
        """Gets the type of this BeolinkJoinResult.  # noqa: E501

        The type of join request this is a result of  # noqa: E501

        :return: The type of this BeolinkJoinResult.  # noqa: E501
        :rtype: 'BeolinkJoinResult.LTypeType'
        """
        return self._type

    @type.setter
    def type(self, type):
        # type: ('BeolinkJoinResult.LTypeType') -> None
        """Sets the type of this BeolinkJoinResult.

        The type of join request this is a result of  # noqa: E501

        :param type: The type of this BeolinkJoinResult.  # noqa: E501
        :type type: 'BeolinkJoinResult.LTypeType'
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation and type is None
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `type`, must not be `None`"
            )  # noqa: E501
        allowed_values = [
            "join",
            "joinRequested",
            "expand",
            "expandRequested",
        ]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and type not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}".format(  # noqa: E501
                    type, allowed_values
                )
            )

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BeolinkJoinResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BeolinkJoinResult):
            return True

        return self.to_dict() != other.to_dict()
